@@ -2,16 +2,16 @@ import sys
 import typing
 
 
-def do_clear_previews(do_objects, do_groups, do_scenes, do_data_intern):
-    ''' 
+def do_clear_previews(do_objects, do_collections, do_scenes, do_data_intern):
+    '''
 
     '''
 
     pass
 
 
-def do_previews(do_objects, do_groups, do_scenes, do_data_intern):
-    ''' 
+def do_previews(do_objects, do_collections, do_scenes, do_data_intern):
+    '''
 
     '''
 
@@ -19,7 +19,7 @@ def do_previews(do_objects, do_groups, do_scenes, do_data_intern):
 
 
 def ids_nolib(bids):
-    ''' 
+    '''
 
     '''
 
@@ -27,7 +27,7 @@ def ids_nolib(bids):
 
 
 def main():
-    ''' 
+    '''
 
     '''
 
@@ -35,7 +35,7 @@ def main():
 
 
 def rna_backup_gen(data, include_props, exclude_props, root):
-    ''' 
+    '''
 
     '''
 
@@ -43,7 +43,7 @@ def rna_backup_gen(data, include_props, exclude_props, root):
 
 
 def rna_backup_restore(data, backup):
-    ''' 
+    '''
 
     '''
 
