@@ -1,15 +1,14 @@
 import sys
 import typing
-import bpy.types
-
-from . import types
 from . import ops
+from . import types
 from . import app
-from . import props
-from . import utils
-from . import context
 from . import path
+from . import utils
+from . import props
+from . import context
 
-data: 'bpy.types.BlendData' = None
-''' Access to Blender's internal data
-'''
+context: 'types.Context' = None
+
+data: 'types.BlendData' = None
+'''Access to Blenders internal data '''
