@@ -1,22 +1,17 @@
 import sys
 import typing
-import bpy.types
+active_annotation_layer: 'bpy.types.GPencilLayer' = None
 
 active_base: 'bpy.types.ObjectBase' = None
 
 active_bone: 'bpy.types.EditBone' = None
 
-active_gpencil_brush: 'bpy.types.GPencilSculptBrush' = None
+active_editable_fcurve: 'bpy.types.FCurve' = None
 
 active_gpencil_frame: list = None
 
 active_gpencil_layer: typing.List['bpy.types.GPencilLayer'] = None
 
-active_gpencil_palette: typing.List['bpy.types.GPencilPalette'] = None
-
-active_gpencil_palettecolor: typing.List[
-    'bpy.types.GPencilPaletteColor'] = None
-
 active_node: 'bpy.types.Node' = None
 
 active_object: 'bpy.types.Object' = None
@@ -25,6 +20,10 @@ active_operator: 'bpy.types.Operator' = None
 
 active_pose_bone: 'bpy.types.PoseBone' = None
 
+annotation_data: 'bpy.types.GreasePencil' = None
+
+annotation_data_owner: 'bpy.types.ID' = None
+
 area: 'bpy.types.Area' = None
 
 armature: 'bpy.types.Armature' = None
@@ -39,6 +38,8 @@ camera: 'bpy.types.Camera' = None
 
 cloth: 'bpy.types.ClothModifier' = None
 
+collection: 'bpy.types.Collection' = None
+
 collision: 'bpy.types.CollisionModifier' = None
 
 curve: 'bpy.types.Curve' = None
@@ -57,28 +58,38 @@ edit_object: 'bpy.types.Object' = None
 
 edit_text: 'bpy.types.Text' = None
 
-editable_bases: typing.List['bpy.types.ObjectBase'] = None
-
 editable_bones: typing.List['bpy.types.EditBone'] = None
 
+editable_fcurves: typing.List['bpy.types.FCurve'] = None
+
 editable_gpencil_layers: typing.List['bpy.types.GPencilLayer'] = None
 
 editable_gpencil_strokes: typing.List['bpy.types.GPencilStroke'] = None
 
 editable_objects: typing.List['bpy.types.Object'] = None
 
-fluid: 'bpy.types.FluidSimulationModifier' = None
+engine: str = None
 
-gpencil_data = None
+fluid = None
+
+gizmo_group: 'bpy.types.GizmoGroup' = None
+
+gpencil: 'bpy.types.GreasePencil' = None
+
+gpencil_data: 'bpy.types.GreasePencil' = None
 
 gpencil_data_owner: 'bpy.types.ID' = None
 
 image_paint_object: 'bpy.types.Object' = None
 
-lamp: 'bpy.types.Lamp' = None
-
 lattice: 'bpy.types.Lattice' = None
 
+layer_collection: 'bpy.types.LayerCollection' = None
+
+light: 'bpy.types.Light' = None
+
+lightprobe: 'bpy.types.LightProbe' = None
+
 line_style: 'bpy.types.FreestyleLineStyle' = None
 
 material: 'bpy.types.Material' = None
@@ -89,10 +100,14 @@ mesh: 'bpy.types.Mesh' = None
 
 meta_ball: 'bpy.types.MetaBall' = None
 
-mode: typing.Union[int, str] = None
+mode: typing.Union[str, int] = None
 
 object: 'bpy.types.Object' = None
 
+objects_in_mode: typing.List['bpy.types.Object'] = None
+
+objects_in_mode_unique_data: typing.List['bpy.types.Object'] = None
+
 particle_edit_object: 'bpy.types.Object' = None
 
 particle_settings: 'bpy.types.ParticleSettings' = None
@@ -103,6 +118,10 @@ particle_system_editable: 'bpy.types.ParticleSystem' = None
 
 pose_bone: 'bpy.types.PoseBone' = None
 
+pose_object: 'bpy.types.Object' = None
+
+preferences: 'bpy.types.Preferences' = None
+
 region: 'bpy.types.Region' = None
 
 region_data: 'bpy.types.RegionView3D' = None
@@ -113,18 +132,14 @@ screen: 'bpy.types.Screen' = None
 
 sculpt_object: 'bpy.types.Object' = None
 
-selectable_bases: typing.List['bpy.types.ObjectBase'] = None
-
 selectable_objects: typing.List['bpy.types.Object'] = None
 
-selected_bases: typing.List['bpy.types.ObjectBase'] = None
-
 selected_bones: typing.List['bpy.types.EditBone'] = None
 
-selected_editable_bases: typing.List['bpy.types.ObjectBase'] = None
-
 selected_editable_bones: typing.List['bpy.types.EditBone'] = None
 
+selected_editable_fcurves: typing.List['bpy.types.FCurve'] = None
+
 selected_editable_objects: typing.List['bpy.types.Object'] = None
 
 selected_editable_sequences: typing.List['bpy.types.Sequence'] = None
@@ -135,11 +150,14 @@ selected_objects: typing.List['bpy.types.Object'] = None
 
 selected_pose_bones: typing.List['bpy.types.PoseBone'] = None
 
+selected_pose_bones_from_active_object: typing.List[
+    'bpy.types.PoseBone'] = None
+
 selected_sequences: typing.List['bpy.types.Sequence'] = None
 
-sequences: typing.List['bpy.types.Sequence'] = None
+selected_visible_fcurves: typing.List['bpy.types.FCurve'] = None
 
-smoke: 'bpy.types.SmokeModifier' = None
+sequences: typing.List['bpy.types.Sequence'] = None
 
 soft_body: 'bpy.types.SoftBodyModifier' = None
 
@@ -149,7 +167,7 @@ speaker: 'bpy.types.Speaker' = None
 
 texture: 'bpy.types.Texture' = None
 
-texture_slot: 'bpy.types.MaterialTextureSlot' = None
+texture_slot = None
 
 texture_user: 'bpy.types.ID' = None
 
@@ -157,14 +175,14 @@ texture_user_property: 'bpy.types.Property' = None
 
 tool_settings: 'bpy.types.ToolSettings' = None
 
-user_preferences: 'bpy.types.UserPreferences' = None
-
 vertex_paint_object: 'bpy.types.Object' = None
 
-visible_bases: typing.List['bpy.types.ObjectBase'] = None
+view_layer: 'bpy.types.ViewLayer' = None
 
 visible_bones: typing.List['bpy.types.EditBone'] = None
 
+visible_fcurves: typing.List['bpy.types.FCurve'] = None
+
 visible_gpencil_layers: typing.List['bpy.types.GPencilLayer'] = None
 
 visible_objects: typing.List['bpy.types.Object'] = None
@@ -177,4 +195,6 @@ window: 'bpy.types.Window' = None
 
 window_manager: 'bpy.types.WindowManager' = None
 
+workspace: 'bpy.types.WorkSpace' = None
+
 world: 'bpy.types.World' = None
