@@ -1,76 +1,75 @@
 import sys
 import typing
-from . import group
-from . import import_scene
-from . import gpencil
-from . import transform
-from . import object
-from . import ed
-from . import buttons
-from . import sculpt
-from . import console
-from . import export_anim
-from . import material
-from . import paint
-from . import export_scene
-from . import rigidbody
-from . import script
-from . import pose
-from . import texture
-from . import paintcurve
-from . import info
-from . import sound
-from . import lamp
-from . import time
-from . import screen
-from . import sketch
-from . import cycles
-from . import cloth
-from . import world
-from . import view2d
-from . import clip
-from . import export_mesh
-from . import sequencer
-from . import poselib
-from . import curve
-from . import wm
-from . import ui
-from . import dpaint
-from . import outliner
-from . import file
 from . import uv
-from . import scene
-from . import view3d
-from . import node
-from . import cachefile
-from . import image
+from . import ui
+from . import gizmogroup
+from . import anim
+from . import workspace
 from . import import_curve
 from . import graph
-from . import marker
-from . import mesh
-from . import anim
-from . import camera
 from . import boid
-from . import import_anim
-from . import render
-from . import action
-from . import safe_areas
-from . import particle
-from . import brush
-from . import fluid
-from . import nla
-from . import constraint
+from . import cachefile
+from . import export_anim
 from . import ptcache
+from . import sculpt
+from . import sequencer
+from . import font
+from . import node
+from . import mask
+from . import paintcurve
+from . import file
+from . import image
+from . import cloth
+from . import rigidbody
+from . import safe_areas
+from . import mball
+from . import preferences
+from . import import_scene
+from . import nla
+from . import material
+from . import scene
+from . import clip
+from . import ed
+from . import action
+from . import collection
+from . import marker
+from . import sound
+from . import particle
+from . import outliner
+from . import texture
+from . import wm
+from . import view2d
+from . import text
+from . import camera
+from . import gpencil
+from . import poselib
+from . import pose
+from . import fluid
+from . import export_mesh
+from . import cycles
+from . import constraint
+from . import mesh
+from . import transform
+from . import buttons
+from . import dpaint
+from . import view3d
+from . import console
+from . import screen
+from . import lattice
+from . import world
+from . import info
 from . import import_mesh
 from . import palette
+from . import curve
+from . import object
+from . import export_scene
 from . import surface
-from . import logic
-from . import lattice
-from . import mask
-from . import font
-from . import mball
+from . import import_anim
+from . import script
 from . import armature
-from . import text
+from . import brush
+from . import paint
+from . import render
 
 
 class BPyOps:
@@ -82,32 +81,26 @@ class BPyOpsSubMod:
 
 
 class BPyOpsSubModOp:
-    def get_instance(self):
-        ''' 
-
+    def get_rna_type(self):
         '''
-        pass
-
-    def get_rna(self):
-        ''' 
 
         '''
         pass
 
     def idname(self):
-        ''' 
+        '''
 
         '''
         pass
 
     def idname_py(self):
-        ''' 
+        '''
 
         '''
         pass
 
     def poll(self, args):
-        ''' 
+        '''
 
         '''
         pass
