@@ -3,7 +3,7 @@ import typing
 
 
 def add():
-    ''' Add new cache
+    '''Add new cache 
 
     '''
 
@@ -11,9 +11,9 @@ def add():
 
 
 def bake(bake: bool = False):
-    ''' Bake physics
+    '''Bake physics 
 
-    :param bake: Bake
+    :param bake: Bake 
     :type bake: bool
     '''
 
@@ -21,9 +21,9 @@ def bake(bake: bool = False):
 
 
 def bake_all(bake: bool = True):
-    ''' Bake all physics
+    '''Bake all physics 
 
-    :param bake: Bake
+    :param bake: Bake 
     :type bake: bool
     '''
 
@@ -31,7 +31,7 @@ def bake_all(bake: bool = True):
 
 
 def bake_from_cache():
-    ''' Bake from cache
+    '''Bake from cache 
 
     '''
 
@@ -39,7 +39,7 @@ def bake_from_cache():
 
 
 def free_bake():
-    ''' Free physics bake
+    '''Delete physics bake 
 
     '''
 
@@ -47,7 +47,7 @@ def free_bake():
 
 
 def free_bake_all():
-    ''' Free all baked caches of all objects in the current scene
+    '''Delete all baked caches of all objects in the current scene 
 
     '''
 
@@ -55,7 +55,7 @@ def free_bake_all():
 
 
 def remove():
-    ''' Delete current cache
+    '''Delete current cache 
 
     '''
 
