@@ -10,7 +10,7 @@ def add_scrollback(text, text_type):
     pass
 
 
-def autocomplete(context):
+def autocomplete(_context):
     '''
 
     '''
@@ -26,7 +26,7 @@ def banner(context):
     pass
 
 
-def execute(context, is_interactive):
+def execute(context, _is_interactive):
     '''
 
     '''
