@@ -2,40 +2,40 @@ import sys
 import typing
 
 
-def RKS_GEN_available(ksi, context, ks, data):
-    ''' 
+def RKS_GEN_available(_ksi, _context, ks, data):
+    '''
 
     '''
 
     pass
 
 
-def RKS_GEN_bendy_bones(ksi, context, ks, data):
-    ''' 
+def RKS_GEN_bendy_bones(_ksi, _context, ks, data):
+    '''
 
     '''
 
     pass
 
 
-def RKS_GEN_location(ksi, context, ks, data):
-    ''' 
+def RKS_GEN_location(_ksi, _context, ks, data):
+    '''
 
     '''
 
     pass
 
 
-def RKS_GEN_rotation(ksi, context, ks, data):
-    ''' 
+def RKS_GEN_rotation(_ksi, _context, ks, data):
+    '''
 
     '''
 
     pass
 
 
-def RKS_GEN_scaling(ksi, context, ks, data):
-    ''' 
+def RKS_GEN_scaling(_ksi, _context, ks, data):
+    '''
 
     '''
 
@@ -43,7 +43,7 @@ def RKS_GEN_scaling(ksi, context, ks, data):
 
 
 def RKS_ITER_selected_bones(ksi, context, ks):
-    ''' 
+    '''
 
     '''
 
@@ -51,7 +51,7 @@ def RKS_ITER_selected_bones(ksi, context, ks):
 
 
 def RKS_ITER_selected_item(ksi, context, ks):
-    ''' 
+    '''
 
     '''
 
@@ -59,15 +59,15 @@ def RKS_ITER_selected_item(ksi, context, ks):
 
 
 def RKS_ITER_selected_objects(ksi, context, ks):
-    ''' 
+    '''
 
     '''
 
     pass
 
 
-def RKS_POLL_selected_bones(ksi, context):
-    ''' 
+def RKS_POLL_selected_bones(_ksi, context):
+    '''
 
     '''
 
@@ -75,15 +75,15 @@ def RKS_POLL_selected_bones(ksi, context):
 
 
 def RKS_POLL_selected_items(ksi, context):
-    ''' 
+    '''
 
     '''
 
     pass
 
 
-def RKS_POLL_selected_objects(ksi, context):
-    ''' 
+def RKS_POLL_selected_objects(_ksi, context):
+    '''
 
     '''
 
@@ -91,7 +91,7 @@ def RKS_POLL_selected_objects(ksi, context):
 
 
 def get_transform_generators_base_info(data):
-    ''' 
+    '''
 
     '''
 
@@ -99,7 +99,7 @@ def get_transform_generators_base_info(data):
 
 
 def path_add_property(path, prop):
-    ''' 
+    '''
 
     '''
 
