@@ -4,26 +4,29 @@ import typing
 
 class PropertyPanel:
     bl_label = None
-    ''' '''
+    ''''''
 
     bl_options = None
-    ''' '''
+    ''''''
+
+    bl_order = None
+    ''''''
 
     def draw(self, context):
-        ''' 
+        '''
 
         '''
         pass
 
     def poll(self, context):
-        ''' 
+        '''
 
         '''
         pass
 
 
 def draw(layout, context, context_member, property_type, use_edit):
-    ''' 
+    '''
 
     '''
 
@@ -31,7 +34,7 @@ def draw(layout, context, context_member, property_type, use_edit):
 
 
 def rna_idprop_context_value(context, context_member, property_type):
-    ''' 
+    '''
 
     '''
 
@@ -39,7 +42,24 @@ def rna_idprop_context_value(context, context_member, property_type):
 
 
 def rna_idprop_has_properties(rna_item):
-    ''' 
+    '''
+
+    '''
+
+    pass
+
+
+def rna_idprop_quote_path(prop):
+    '''
+
+    '''
+
+    pass
+
+
+def rna_idprop_ui_create(item, prop, default, min, max, soft_min, soft_max,
+                         description, overridable, subtype):
+    '''
 
     '''
 
@@ -47,7 +67,7 @@ def rna_idprop_has_properties(rna_item):
 
 
 def rna_idprop_ui_del(item):
-    ''' 
+    '''
 
     '''
 
@@ -55,7 +75,7 @@ def rna_idprop_ui_del(item):
 
 
 def rna_idprop_ui_get(item, create):
-    ''' 
+    '''
 
     '''
 
@@ -63,7 +83,15 @@ def rna_idprop_ui_get(item, create):
 
 
 def rna_idprop_ui_prop_clear(item, prop, remove):
-    ''' 
+    '''
+
+    '''
+
+    pass
+
+
+def rna_idprop_ui_prop_default_set(item, prop, value):
+    '''
 
     '''
 
@@ -71,7 +99,7 @@ def rna_idprop_ui_prop_clear(item, prop, remove):
 
 
 def rna_idprop_ui_prop_get(item, prop, create):
-    ''' 
+    '''
 
     '''
 
@@ -79,7 +107,23 @@ def rna_idprop_ui_prop_get(item, prop, create):
 
 
 def rna_idprop_ui_prop_update(item, prop):
-    ''' 
+    '''
+
+    '''
+
+    pass
+
+
+def rna_idprop_value_item_type(value):
+    '''
+
+    '''
+
+    pass
+
+
+def rna_idprop_value_to_python(value):
+    '''
 
     '''
 
